@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.19';
+our $VERSION = '1.20';
 
 use Carp;
 use Fcntl qw(:flock);
@@ -15,7 +15,6 @@ sub new {
     return bless {}, shift;
 }
 sub read {
-
     my $self = shift;
     my ($file, $testing);
 
@@ -32,7 +31,7 @@ sub read {
     $testing = $self->{testing};
 
     if (! $file){ 
-        croak "read() requires a file name sent in!";
+        confess "read() requires a file name sent in!";
     }
 
     $self->recsep($file);
@@ -47,7 +46,7 @@ sub read {
     else {
         $fh = $self->_open($file); 
         my @contents = <$fh>;
-        close $fh or croak "read() can't close file $file!: $!";
+        close $fh or confess "read() can't close file $file!: $!";
 
         if (! $testing){
             for (@contents){
@@ -58,30 +57,24 @@ sub read {
     }
 }
 sub write {
-
     my $self = shift;
     $self->_config(@_);
 
-    my $file = $self->{file};
-    my $copy = $self->{copy};
-    my $contents = $self->{contents};
-    my $recsep = $self->{custom_recsep};
-
-    if (! $file){
-        croak "write() requires a file to be passed in!";
+    if (! $self->{file}){
+        confess "write() requires a file to be passed in!";
     }
 
-    if (! $contents){
-        croak "write() requires 'contents' param sent in";
+    if (! $self->{contents}){
+        confess "write() requires 'contents' param sent in";
     }
 
     if (! $self->{is_read}){
-        $self->recsep($file);
+        $self->recsep($self->{file});
     }
 
-    $file = $copy if $copy;
+    $self->{file} = $self->{copy} if $self->{copy};
 
-    my $wfh = $self->_open($file, 'w');
+    my $wfh = $self->_open($self->{file}, 'w');
 
     # certain FreeBSD versions on amd64 don't work
     # with flock()
@@ -92,9 +85,11 @@ sub write {
         flock $wfh, LOCK_EX;
     }
 
-    $recsep = defined $recsep ? $recsep : $self->{recsep};
+    my $recsep = defined $self->{custom_recsep}
+        ? $self->{custom_recsep}
+        : $self->{recsep};
 
-    # is contents a fh?
+    my $contents = $self->{contents};
 
     if (ref($contents) eq 'GLOB' || ref($contents) eq 'File::Temp'){
         seek $contents, 0, 0;
@@ -118,23 +113,22 @@ sub write {
     return 1;
 }
 sub splice {
-
     my $self = shift;
     $self->_config(@_);
 
     my $file = $self->{file};
     my $copy = $self->{copy};
     my $insert = $self->{insert};
-    my $find = $self->{find};
-    my $line = $self->{line};
     my $limit = defined $self->{limit} ? $self->{limit} : 1;
 
     if (! $insert){
-        croak "splice() requires insert => [aref] param";
+        confess "splice() requires insert => [aref] param";
     }
 
+    my ($line, $find) = ($self->{line}, $self->{find});
+
     if (! defined $line && ! defined $find){
-        croak "splice() requires either the 'line' or 'find' parameter sent in.";
+        confess "splice() requires either the 'line' or 'find' parameter sent in.";
     }
 
     if (defined $line && defined $find){
@@ -146,7 +140,7 @@ sub splice {
 
     if (defined $line){
         if ($line !~ /^[0-9]+$/){
-            croak "splice() requires its 'line' param to contain only an " .
+            confess "splice() requires its 'line' param to contain only an " .
                   "integer. You supplied: $line\n";
         }
         splice @contents, $line, 0, @$insert;
@@ -175,7 +169,6 @@ sub splice {
     return @contents;
 }
 sub dir {
-    
     my $self = shift;
     $self->_config(@_);
 
@@ -213,14 +206,15 @@ sub dir {
         $self->write(
                     file => $file, 
                     contents => $wfh,
-                    recsep => defined $recsep ? $recsep : $self->platform_recsep,
+                    recsep => defined $recsep
+                        ? $recsep
+                        : $self->platform_recsep,
                 );
     }
 
     return @files;
 }
 sub recsep {
-
     my $self = shift;
     my $file = shift;
     my $hex = shift if @_;
@@ -256,7 +250,7 @@ sub recsep {
         $self->{recsep} = $1;
     }
 
-    close $fh or croak "recsep() can't close file $file!: $!";
+    close $fh or confess "recsep() can't close file $file!: $!";
    
     if ($hex){ 
         $recsep = unpack "H*", $self->{recsep};
@@ -274,9 +268,6 @@ sub platform_recsep {
 
     my $file = $self->_temp_filename;
 
-    # this is for checking to see if we've cleaned up
-    # in DESTROY
-
     push @{ $self->{temp_files} }, $file;
 
     # for platform_recsep(), we need the file open in ASCII mode,
@@ -288,7 +279,7 @@ sub platform_recsep {
     print $wfh "abc\n";
 
     close $wfh
-      or croak "platform_recsep() can't close write temp file $file: $!";
+      or confess "platform_recsep() can't close write temp file $file: $!";
 
     my $fh = $self->_open($file);
 
@@ -297,7 +288,7 @@ sub platform_recsep {
     }
 
     close $fh
-      or croak "platform_recsep() can't close temp file $file after run: $!";
+      or confess "platform_recsep() can't close temp file $file after run: $!";
 
     if ($hex){
         my $recsep = unpack "H*", $self->{platform_recsep};
@@ -313,7 +304,6 @@ sub tempfile {
     return $wfh;
 }
 sub _config {
-
     my $self = shift;
     my %p = @_;
 
@@ -334,7 +324,6 @@ sub _config {
     }
 }
 sub _handle {
-
     # returns a handle with platform's record separator
 
     my $self = shift;
@@ -350,9 +339,6 @@ sub _handle {
 
         my $temp_filename = $temp_wfh->filename;
 
-        # we'll check these in DESTROY to make sure we've
-        # cleaned up appropriately
-
         push @{ $self->{temp_files} }, $temp_filename;
 
         my $platform_recsep = $self->platform_recsep;
@@ -375,7 +361,6 @@ sub _handle {
     }
 }
 sub _open {
-
     # returns a handle opened with binmode :raw
 
     my $self = shift;
@@ -386,11 +371,11 @@ sub _open {
 
     if ($mode =~ /^w/){
         open $fh, '>', $file
-          or croak "_open() can't open file $file for writing!: $!";
+          or confess "_open() can't open file $file for writing!: $!";
     }
     else {
         open $fh, '<', $file
-          or croak "_open() can't open file $file for reading!: $!";
+          or confess "_open() can't open file $file for reading!: $!";
     }
 
     binmode $fh, ':raw';
@@ -398,7 +383,6 @@ sub _open {
     return $fh;
 }
 sub _temp_filename {
-
     my $self = shift;
 
     my $temp_fh = File::Temp->new(UNLINK => 1);
@@ -406,19 +390,18 @@ sub _temp_filename {
     my $file = $temp_fh->filename;
 
     close $temp_fh
-     or croak "_temp_filename() can't close the $file temp file: $!";
+     or confess "_temp_filename() can't close the $file temp file: $!";
 
     return $file;
 }
 sub DESTROY {
-    
     my $self = shift;
 
     for (@{ $self->{temp_files} }){
         if (-f && $^O ne 'MSWin32'){
             eval { unlink $_ or die $!; };
             if ($@){
-                croak "File::Temp didn't unlink $_ temp file, and we " .
+                confess "File::Temp didn't unlink $_ temp file, and we " .
                       "can't unlink it in our DESTROY() either!: $@";
             }
         }
